@@ -5,7 +5,7 @@
 .onLoad <- function(lib, pkg) {
 	# remove the require() call for 2.0.0:
 	# require(lattice)
-	.Call(gstat_init, as.integer(1))
+	# .Call(gstat_init, as.integer(1))
 }
 
 ### pre-NAMESPACE VERSION:
